# queky

### Instalestion
`pip install queky`

### Usage is the How to opereting:
1. open terminal
2. type `qk`
3. the tool should activate if installed correctly
4. get a gemini [api key](https://aistudio.google.com/app/apikey)
5. copy questions
6. just press enter in the terminal (it will automatically capture and paste everything in the clipboard)
7. you should receive your answers